pub struct QueryContext {
pub context_type: QueryContextType,
pub object_type: String,
pub object_name: String,
pub start_index: i32,
pub stop_index: i32,
pub fragment: String,
pub call_site: String,
pub summary: String,
}Expand description
Query context describing where an error occurred.
Fields
context_type: QueryContextTypeobject_type: Stringobject_name: Stringstart_index: i32stop_index: i32fragment: Stringcall_site: Stringsummary: StringImplementations
Sourceimpl QueryContext
impl QueryContext
Sourcepub fn new(
context_type: QueryContextType,
object_type: String,
object_name: String,
start_index: i32,
stop_index: i32,
fragment: String,
call_site: String,
summary: String,
) -> Self
pub fn new( context_type: QueryContextType, object_type: String, object_name: String, start_index: i32, stop_index: i32, fragment: String, call_site: String, summary: String, ) -> Self
Create a new QueryContext.
Sourcepub fn context_type(&self) -> QueryContextType
pub fn context_type(&self) -> QueryContextType
Get the context type.
Sourcepub fn object_type(&self) -> &str
pub fn object_type(&self) -> &str
Get the object type (e.g., “VIEW”, or empty string for main query).
Sourcepub fn object_name(&self) -> &str
pub fn object_name(&self) -> &str
Get the object name (e.g., view name, or empty string for main query).
Sourcepub fn start_index(&self) -> i32
pub fn start_index(&self) -> i32
Get the starting index in the query text (0-based).
Sourcepub fn stop_index(&self) -> i32
pub fn stop_index(&self) -> i32
Get the stopping index in the query text (0-based).